@@ -42,7 +42,6 @@ import cairo
 if sys.platform=='win32':
 	import win32api
 
-
 import devede_other
 import devede_video_convert
 import devede_subtitles
@@ -57,7 +56,6 @@ import gc
 
 class create_all:
 
-
 	def cancel_clicked(self,widget,temp=False):
 		
 		newtree=gtk.glade.XML(self.gladefile,"wcancel_job_dialog",domain="devede")
@@ -107,7 +105,7 @@ class create_all:
 		w.set_sensitive(mode)
 
 
-	def check_free_space(self,filefolder,structure,actions,erase_temporary_files):
+	def check_free_space(self,filefolder,structure,actions,erase_temporary_files,sound_duration):
 
 		""" Returns TRUE if the free space in FILEFOLDER is insuficient to generate
 		the disk STRUCTURE """
@@ -115,6 +113,7 @@ class create_all:
 		estado=''
 		freespace=''
 		if sys.platform!='win32':
+			print "Checking "+str(filefolder)
 			estado=os.statvfs(filefolder) # eg. f="C:\Documents and Settings\User name\Desktop"
 			freespace=95*estado.f_bsize*estado.f_bavail/100000
 		else:
@@ -127,7 +126,7 @@ class create_all:
 		print "Free space in "+str(filefolder)+": "+str(freespace)
 		print "estatus ", estado, "\n"
 	
-		total=devede_other.calcula_tamano_total(structure)
+		total=devede_other.calcula_tamano_total(structure,sound_duration,self.disk_type)
 
 		print "Free: "+str(freespace)
 		print "Needed: "+str(total)
@@ -142,7 +141,7 @@ class create_all:
 		total*=1.1 # a safe margin of 10%
 
 		if (freespace<total):
-			return True,_("Insuficient free space. To create this disk\n%(total)d MBytes are needed, but only %(free)d MBytes are available.") % {'total':int(total/1000),'free':int(freespace/1000)}
+			return True,_("Insuficient free space. To create this disc\n%(total)d MBytes are needed, but only %(free)d MBytes are available.") % {'total':int(total/1000),'free':int(freespace/1000)}
 		else:
 			return False,""
 
@@ -158,22 +157,9 @@ class create_all:
 		self.window=self.tree.get_widget("wprogress")
 		self.partial=self.tree.get_widget("progresspartial")
 		self.erase_temp=global_vars["erase_temporary_files"]
-		
-		total=0
-		
-		self.queue=[]
-		title=0
-		for element in structure:
-			chapter=0
-			for element2 in element[1:]:
-				self.queue.append(["C",title,chapter])
-				stream=0
-				for element3 in element2["sub_list"]:
-					self.queue.append(["S",title,chapter,stream])
-					stream+=1
-				chapter+=1
-			title+=1
+		self.iso_creator=global_vars["iso_creator"]
 
+		self.queue=[]
 		self.current_action=0
 		self.actions=global_vars["number_actions"]
 		self.total=self.tree.get_widget("progress_total")
@@ -188,8 +174,25 @@ class create_all:
 		self.tiempo=time.time()
 
 
+	def init_queue(self):
+
+		total=0
+		title=0
+		for element in self.structure:
+			chapter=0
+			for element2 in element[1:]:
+				self.queue.append(["C",title,chapter])
+				stream=0
+				for element3 in element2["sub_list"]:
+					self.queue.append(["S",title,chapter,stream])
+					stream+=1
+				chapter+=1
+			title+=1
+
+
 	def preview(self,filefolder):
 		
+		self.init_queue()
 		newtree=gtk.glade.XML(self.gladefile,"wpreview_dialog",domain="devede")
 		timev=newtree.get_widget("seconds_preview")
 		timev.set_value(60)
@@ -266,17 +269,46 @@ class create_all:
 		w=newtree.get_widget("wfolder_dialog")
 		w.show()
 		value=w.run()
+		
 		self.filename=wfile.get_text()
-		self.filefolder=wdir.get_filename()
-		if self.filefolder[-1]!=os.sep:
-			self.filefolder+=os.sep
+		filefolder=wdir.get_filename()
+		
 		w.hide()
 		w.destroy()
 		if value!=-6:
 			return False
+		
+		filefolder2=os.path.join(filefolder,self.filename)
+		
+		self.filefolder=filefolder2
+		
+		if self.filefolder[-1]!=os.sep:
+			self.filefolder+=os.sep
+		
+		if (os.path.exists(filefolder2)):
+			newtree=gtk.glade.XML(self.gladefile,"wfolder_exists",domain="devede")
+			w=newtree.get_widget("wfolder_exists")
+			wtext=newtree.get_widget("folder_exists_label")
+			wtext.set_text(_("The file or folder\n\n%(folder)s\n\nalready exists. If you continue, it will be deleted.") % {'folder':filefolder2})
+			w.show()
+			value=w.run()
+			w.hide()
+			w.destroy()
+			if value!=2:
+				return False
+		
+		try:
+			os.remove(filefolder2)
+		except:
+			pass
+		
+		try:
+			os.mkdir(filefolder2)
+		except:
+			pass
 	
 		self.eraser=devede_delete.delete_files(self.filename,self.filefolder)
-		hasfree,msg=self.check_free_space(self.filefolder,self.structure,self.actions,self.erase_temp)
+		hasfree,msg=self.check_free_space(self.filefolder,self.structure,self.actions,self.erase_temp,self.global_vars["menu_sound_duration"])
 		if hasfree:
 			self.window.hide()
 			self.window.destroy()
@@ -290,17 +322,27 @@ class create_all:
 		
 		# now, create the XML files (even with VCD, SVCD or CVD, to check if we have write permissions)
 
-		xml_files=devede_xml_menu.xml_files()
-		retorno=xml_files.create_files(self.filename,self.filefolder,self.structure,self.global_vars["do_menu"],self.global_vars["menu_PAL"],self.global_vars["menu_widescreen"],self.global_vars["path"],self.global_vars["menu_bg"],self.global_vars["fontname"],self.global_vars["path"],self.global_vars["menu_bgcolor"],self.global_vars["menu_font_color"],self.global_vars["menu_selc_color"],self.global_vars["menu_alignment"])
+		xml_files=devede_xml_menu.xml_files(self.partial,self.filename,self.filefolder,self.structure,self.global_vars,self.label)
+
+		counter=0
+		counter2=0
+		if (self.disk_type=="dvd"):
+			nelements=xml_files.get_elements_per_menu()
+			while (len(self.structure[counter:])!=0):
+				self.queue.append(["M1",xml_files,counter,counter2])
+				counter+=nelements
+				counter2+=1
+
+		self.init_queue()
+
+		retorno=xml_files.create_files()
 		if retorno!=None:
 			self.window.hide()
 			self.window.destroy()
 			self.show_error(retorno)
 			(self.main_window_callback)()
 			return False
-	
-		xml_files.end_process(self.eraser,self.erase_temp)
-		xml_files=None
+		
 		self.runner=None
 		if self.actions!=1: # want to do, at least, the DVD structure, or the VCD image
 			if self.disk_type=="dvd":
@@ -323,13 +365,20 @@ class create_all:
 		""" This method launches all the conversion stages when needed, using the standard executor
 		interface to manage all of them in an easy way """
 
+		self.total.set_text(str(self.current_action)+"/"+str(len(self.queue)-1))
+		self.total.set_fraction(float(self.current_action)/(float(len(self.queue)-1)))
 		if self.runner!=None:
 			retval=self.runner.refresh()
 			if retval==0: # no error, still running
 				return True
 			else:
+				self.current_action+=1
 				retval=self.runner.wait_end()
 				if retval!=0:
+					self.window.hide()
+					self.window.destroy()
+					if self.runner.print_error==None:
+						self.runner.print_error=_("Unknown error")
 					self.show_error(self.runner.print_error)
 					(self.main_window_callback)()
 					return False
@@ -338,9 +387,11 @@ class create_all:
 				self.runner=None
 		
 		action=self.queue[self.current_action]
-		self.total.set_text(str(self.current_action)+"/"+str(len(self.queue)-1))
-		self.total.set_fraction(float(self.current_action)/(float(len(self.queue)-1)))
-		self.current_action+=1
+		
+		if action[0]=="M1":
+			self.runner=action[1]
+			self.runner.create_menu1(action[2],action[3],self.global_vars["multicore"])
+			return True
 		
 		if action[0]=="C":
 			title=action[1]
@@ -394,7 +445,7 @@ class create_all:
 			return True
 
 		if action[0]=="DVD_IMAGE":
-			self.runner=devede_bincue.iso_generator(self.filename,self.filefolder,self.partial,self.label)
+			self.runner=devede_bincue.iso_generator(self.filename,self.filefolder,self.partial,self.label,self.iso_creator)
 			return True
 		
 		if action[0]=="END":
