@@ -29,6 +29,7 @@ import devede_dialogs
 class disctype:
 	
 	def __init__(self,global_vars):
+
 		self.gladefile=global_vars["gladefile"]
 		self.global_vars=global_vars
 		
@@ -42,6 +43,17 @@ class disctype:
 	def on_wdisk_type_delete_event(self,widget,signal):
 		""" Callback which shows the "Are you sure?" window """
 	
+		self.ask_cancel()
+	
+	
+	def on_wdisk_type_cancel_clicked(self,widget):
+		""" Callback which shows the "Are you sure?" window """
+	
+		self.ask_cancel()
+	
+	
+	def ask_cancel(self):
+	
 		window=devede_dialogs.ask_exit(self.gladefile)
 		retval=window.run()
 		window=None
@@ -49,48 +61,47 @@ class disctype:
 			gtk.main_quit()
 			return False
 		return True
-	
-	
-	def on_typedvd_clicked(self,widget):
 
+	
+	def on_disctype_dvd(self,widget):
+	
 		self.global_vars["disctocreate"]="dvd"
 		self.set_disk_type()
 
 		
-	def on_typevcd_clicked(self,widget):
+	def on_disctype_vcd(self,widget):
 	
 		self.global_vars["disctocreate"]="vcd"
 		self.set_disk_type()
 
-	
-	def on_typesvcd_clicked(self,widget):
+		
+	def on_disctype_svcd(self,widget):
 	
 		self.global_vars["disctocreate"]="svcd"
 		self.set_disk_type()
 
-	
-	def on_typecvd_clicked(self,widget):
+		
+	def on_disctype_cvd(self,widget):
 	
 		self.global_vars["disctocreate"]="cvd"
 		self.set_disk_type()
 
-	
-	def on_typedivx_clicked(self,widget):
+		
+	def on_disctype_divx(self,widget):
 	
 		self.global_vars["disctocreate"]="divx"
 		self.set_disk_type()
-
-
+	
+		
 	def set_disk_type(self):
 		
 		if self.main_window==None:
 			self.main_window=devede_main.main_window(self.global_vars,self.show_again)
-		self.global_vars["action_todo"]=2
-		self.global_vars["erase_files"]=True
 		self.main_window.set_disc_type(True)
 		self.main_window.show()
 		self.window.hide()
 
+
 	def show_again(self):
 		
 		""" Callback which is called from main window when the user wants to change the
