@@ -36,6 +36,7 @@ import devede_other
 import devede_executor
 import devede_convert
 import devede_dialogs
+import devede_help
 
 # How to add new file options:
 
@@ -59,19 +60,8 @@ import devede_dialogs
 # Finally, add the needed code in DEVEDE_LOADSAVE.PY to ensure that old project files
 # work fine with the new options
 
-class newfile(devede_executor.executor):
-	
-	def __init__(self,pal,disctocreate):
-		""" This class manages every new film added. It reads its parameters (resolution, FPS, number of
-		channels...) and allows to generate the default values, both when choosing manually a file from the
-		Properties window, or when dragging&dropping them into the main window """
-		
-		self.pal=pal
-		self.disctocreate=disctocreate
-		self.file_values=None
-		self.file_properties=None
+class file_get_params(devede_executor.executor):
 
-				
 	def read_file_values(self,filename,check_audio):
 
 		""" Reads the values of the video (width, heigth, fps...) and stores them
@@ -94,6 +84,7 @@ class newfile(devede_executor.executor):
 		video=0
 		audiorate=0
 		aspect_ratio=1.3333333333
+		self.length=0
 
 		# if CHECK_AUDIO is TRUE, we just check if it's an audio file
 
@@ -130,7 +121,7 @@ class newfile(devede_executor.executor):
 				aspect_ratio=float(linea[16:])
 			if linea[:12]=="ID_VIDEO_FPS":
 				fps2=linea[13:]
-				if ord(fps2[-1])<32:
+				while ord(fps2[-1])<32:
 					fps2=fps2[:-1]
 				posic=linea.find(".")
 				if posic==-1:
@@ -157,6 +148,9 @@ class newfile(devede_executor.executor):
 		handler.wait()
 		
 		if (video==0) or (width==0) or (height==0):
+			if (audio!=0):
+				self.length=length
+				self.audio=audio
 			return False,audio
 		
 		if aspect_ratio==0.0:
@@ -181,7 +175,19 @@ class newfile(devede_executor.executor):
 		
 		return True,0
 
+class newfile(file_get_params):
+	
+	def __init__(self,pal,disctocreate):
+		""" This class manages every new film added. It reads its parameters (resolution, FPS, number of
+		channels...) and allows to generate the default values, both when choosing manually a file from the
+		Properties window, or when dragging&dropping them into the main window """
+		
+		self.pal=pal
+		self.disctocreate=disctocreate
+		self.file_values=None
+		self.file_properties=None
 
+		
 	def get_recomended_resolution(self,vrate,arate,desired_resolution):
 
 		""" Returns the recomended resolution for a video based in its original
@@ -189,7 +195,7 @@ class newfile(devede_executor.executor):
 		
 		 	DESIRED_RESOLUTION is a value from 0 to 7:
 		 	0=auto, 1=720x480, 2=704x480, 3=480x480, 4=352x480, 5=352x240
-		 	6=1280x720, 7=1920x1080
+		 	6=1280x720, 7=1920x1080, 8 160x128
 		 	
 		 	It returns the recomended audio and video rate for that resolution,
 		 	but only if the user hasn't changed them """
@@ -245,8 +251,11 @@ class newfile(devede_executor.executor):
 		elif desired_resolution==7:
 			resx=1920
 			resy=1080
+		elif desired_resolution==8:
+			resx=160
+			resy=128
 	
-		if (((resx==720) and (resy==nheigh1)) or (self.disctocreate=="divx")) and (self.file_values["aspect_ratio"]>=1.77):
+		if (((resx==720) and (resy==nheigh1)) or ((self.disctocreate=="divx") and (desired_resolution!=8))) and (self.file_values["aspect_ratio"]>=1.77):
 			use_widescreen=True
 		else:
 			use_widescreen=False
@@ -426,6 +435,12 @@ class file_properties(newfile):
 		w = self.tree.get_widget("expander_advanced")
 		w.set_expanded(self.global_vars["expand_advanced"])
 		
+		if global_vars["PAL"]:
+			w=self.tree.get_widget("video_pal")
+		else:
+			w=self.tree.get_widget("video_ntsc")
+		w.set_active(True)
+		
 		# Model and view for subtitles
 		# first element: position
 		# second: filename
@@ -459,6 +474,7 @@ class file_properties(newfile):
 		w4 = self.tree.get_widget("res1280x720")
 		w5 = self.tree.get_widget("res1920x1080")
 		w6 = self.tree.get_widget("subtitles_list")
+		w7 = self.tree.get_widget("res160x128")
 
 		if (self.disctocreate == "divx"):
 			w1.show()
@@ -467,6 +483,7 @@ class file_properties(newfile):
 			w4.show()
 			w5.show()
 			w6.hide()
+			w7.show()
 		else:
 			w1.hide()
 			w2.show()
@@ -474,6 +491,7 @@ class file_properties(newfile):
 			w4.hide()
 			w5.hide()
 			w6.show()
+			w7.hide()
 		
 		w=self.tree.get_widget("noaudiotracks")
 		w.hide()
@@ -513,7 +531,10 @@ class file_properties(newfile):
 		w=self.tree.get_widget("moviefile")
 		self.file_filter_videos=gtk.FileFilter()
 		self.file_filter_videos.set_name(_("Video files"))
-		self.file_filter_videos.add_mime_type("video/*")
+		if sys.platform!="win32":
+			self.file_filter_videos.add_mime_type("video/*")
+		else:
+			self.file_filter_videos.add_custom(gtk.FILE_FILTER_FILENAME|gtk.FILE_FILTER_DISPLAY_NAME, self.custom_video_filter)
 		self.file_filter_all=gtk.FileFilter()
 		self.file_filter_all.set_name(_("All files"))
 		self.file_filter_all.add_pattern("*")
@@ -537,11 +558,20 @@ class file_properties(newfile):
 
 	# help methods
 
+	def custom_video_filter(self, filter_info=None, data=None):
+		"""Custom file filter.  Filter for video files when running on win32"""
+		video_types=["wmv", "avi", "asf", "flv", "bin", "vob", "es", "ps", "pes","qt", "mov", "mp4", "mpg", "mpeg", "rm", "mkv", "nut", "nsv", "vivo", "fli", "yuv4mpeg", "cpk","ogm", "asx", "3gp"]
+		if os.path.splitext(filter_info[2])[1][1:] in video_types:
+			return True
+		return False
+
 
 	def get_desired_resolution(self):
 		
 		""" Returns the resolution desired by the user as a single number """
 		
+		if (self.tree.get_widget("res160x128").get_active()):
+			return 8
 		if (self.tree.get_widget("res1920x1080").get_active()):
 			return 7
 		if (self.tree.get_widget("res1280x720").get_active()):
@@ -629,7 +659,9 @@ class file_properties(newfile):
 		w=self.tree.get_widget("deinterlace_l5")
 		if w.get_active():
 			self.file_properties["deinterlace"]="l5"
-		
+		w=self.tree.get_widget("deinterlace_yadif")
+		if w.get_active():
+			self.file_properties["deinterlace"]="yadif"
 		
 		w=self.tree.get_widget("ismpeg")
 		self.file_properties["ismpeg"]=w.get_active()
@@ -671,10 +703,8 @@ class file_properties(newfile):
 		w=self.tree.get_widget("video_pal")
 		if w.get_active():
 			self.file_properties["fps"]=25
-			self.global_vars["PAL"]=True
 		else:
 			self.file_properties["fps"]=30
-			self.global_vars["PAL"]=False
 	
 		if (self.disctocreate=="dvd") or (self.disctocreate=="divx"):
 			w=self.tree.get_widget("aspect_ratio_16_9")
@@ -915,6 +945,11 @@ class file_properties(newfile):
 		print "Temp folder changed to "+str(self.global_vars["temp_folder"])
 
 
+	def on_file_help_clicked(self,widget):
+	
+		help_class=devede_help.show_help(self.gladefile,self.global_vars["help_path"],"file.html")
+
+
 	def callback(self):
 		
 		""" This method is called after a preview """
@@ -1025,7 +1060,7 @@ class file_properties(newfile):
 			if self.file_properties["aspect"]>1.6:
 				w2.set_active(True)
 			else:
-				w1.set_active(False)
+				w1.set_active(True)
 		else:
 			w1.set_sensitive(False)
 			w2.set_sensitive(False)
@@ -1040,6 +1075,12 @@ class file_properties(newfile):
 			w=self.tree.get_widget("res480x480")
 		elif self.file_properties["resolution"]==4: # 352x480
 			w=self.tree.get_widget("res352x480")
+		elif self.file_properties["resolution"]==6: # 1280x720
+			w=self.tree.get_widget("res1280x720")
+		elif self.file_properties["resolution"]==7: # 1920x1080
+			w=self.tree.get_widget("res1920x1080")
+		elif self.file_properties["resolution"]==8: # 160x128
+			w=self.tree.get_widget("res160x128")
 		else:
 			w=self.tree.get_widget("res352x240")
 	
@@ -1417,7 +1458,21 @@ class file_properties(newfile):
 			w.set_text("")
 		else:
 			w2=self.tree.get_widget("ismpeg")
-			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),divide2)
+			props={}
+			props["ofps"]=self.file_properties["ofps"]
+			props["ofps2"]=self.file_properties["ofps2"]
+			w3=self.tree.get_widget("video_pal")
+			if w3.get_active():
+				props["fps"]=25
+			else:
+				props["fps"]=30
+			w3=self.tree.get_widget("copy_audio")
+			props["copy_audio"]=w3.get_active()
+			w3=self.tree.get_widget("ismpeg")
+			props["ismpeg"]=w3.get_active()
+			print "Props: "+str(props)
+			speed1,speed2=devede_other.get_speedup(props)
+			l=devede_other.calcula_tamano_parcial(vrate,arate,self.file_properties["filesize"],self.file_properties["olength"],len(self.file_properties["sub_list"]),w2.get_active(),divide2,speed1,speed2)
 			#if w2.get_active():
 			#	l=int(self.file_properties["filesize"]/1000000)
 			#else:
@@ -1434,6 +1489,7 @@ class file_properties(newfile):
 		else:
 			w.set_text(str(self.file_properties["width"])+"x"+str(self.file_properties["height"]))		
 
+
 class ask_subtitle:
 	
 	def __init__(self,gladefile,filepath,filename=None):
